from django.apps import AppConfig


class NotificationsConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'notifications'


# List get* 
# Filters date 
# Filters for service
# Storing db
# Tables for Services; Available Notification Types; User preferences; Users; Notifications; 
# Reusable Django App; INSTALLED_APPS setting;
# bubbling-firebase-authentication; 
# every app on shared/ not the bubbling-default-service
# pulling timed notifications from the dB to put in a queue
