# Generated by Django 3.2.11 on 2022-12-30 06:07

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Notification',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('icon', models.PositiveSmallIntegerField(verbose_name='Icon')),
                ('sub_icon', models.PositiveSmallIntegerField(verbose_name='Sub icon')),
                ('event_creator', models.PositiveSmallIntegerField(choices=[(1, 'SERVICE1'), (2, 'SERVICE2'), (3, 'SERVICE3'), (4, 'SERVICE4')], default=1, verbose_name='Creator')),
                ('title', models.CharField(max_length=28, verbose_name='Title')),
                ('context', models.TextField(max_length=95, verbose_name='Description')),
                ('event_type', models.PositiveSmallIntegerField(choices=[(1, 'Create New Notification'), (2, 'Update Existing Notification')], default=1, verbose_name='Type')),
                ('dynamic_link', models.CharField(max_length=256, verbose_name='Dynamic link')),
                ('viewed', models.BooleanField(default=False, verbose_name='Viewed')),
                ('valid', models.BooleanField(default=True, verbose_name='Valid')),
                ('valid_until', models.DateTimeField(null=True, verbose_name='Valid until timestamp')),
                ('clicked', models.BooleanField(default=False, verbose_name='Clicked')),
                ('clicked_at', models.DateTimeField(null=True, verbose_name='Clicked at timestamp')),
                ('location', models.CharField(default=None, max_length=32, null=True, verbose_name='Location')),
                ('channel', models.CharField(default=None, max_length=32, null=True, verbose_name='Channel')),
                ('status', models.CharField(default='Not Published', max_length=16, verbose_name='Status')),
                ('routing_key', models.CharField(max_length=32, verbose_name='Routing Key')),
            ],
        ),
    ]
